@@ -1,6 +1,8 @@
 ################
 # Dependencies #
 ################
+import sys
+import pathlib
 import importlib
 from aurora.security import request, redirect, check_cookie, get_cookie, check_session, get_session, set_session
 from aurora.helpers import app_exists
@@ -31,6 +33,11 @@ class Controller(View):
         self.active_lang = self.default_lang
         self.LANGUAGE = ''
 
+        # Inspect the app name from caller file
+        caller = sys._getframe().f_back.f_code.co_filename
+        self.app_name = pathlib.PurePath(caller).parent.name
+        self.app_url = app_exists(self.app_name)['url'] if app_exists(self.app_name)['result'] else False
+
         # Check the language
         if self.multi_lang:
             # Fetch the lang
@@ -38,7 +45,7 @@ class Controller(View):
             lang = path.split('/')[1]
 
             # The root path and apps path
-            if path == '/' or app_exists(lang)['result']:
+            if path == '/' or lang == self.app_url or app_exists(lang)['result']:
                 # active_lang cookie exists
                 if check_cookie('active_lang'):
                     self.active_lang = get_cookie('active_lang')
@@ -84,7 +91,8 @@ class Controller(View):
                 path = request.path
 
                 # The root path
-                if path == '/' or app_exists(path.split('/')[1])['result']:
+                # if path == '/' or app_exists(path.split('/')[1])['result']:
+                if path == '/' or path.split('/')[1] == self.app_url or app_exists(path.split('/')[1])['result']:
                     if check_cookie('active_lang'):
                         return redirect('/' + get_cookie('active_lang') + path)
 
